DittoConfigData class

Class that contains Ditto configs

Annotations
  • @freezed

Constructors

DittoConfigData({required String apiKey, required String projectId, @Assert.new("Uri.tryParse(baseUrl) != null") @Default.new('https://api.dittowords.com') String baseUrl})
Class that contains Ditto configs
factory

Properties

apiKey → String
no setterinherited
baseUrl → String
no setterinherited
copyWith → $DittoConfigDataCopyWith<DittoConfigData>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
projectId → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited