Text class

Annotations
  • @freezed

Constructors

Text({String? key, required String text, String? status, String? notes, List<Variable>? variables, Plurals? plurals, Map<String, Text>? variants, List<String>? tags, bool? isComp, String? componentId})
const
factory
Text.fromJson(Map<String, dynamic> json)
factory

Properties

componentId String?
no setterinherited
copyWith → $TextCopyWith<Text>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isComp bool?
no setterinherited
key String?
Viene valorizzato solo se è una chiave di primo livello
no setterinherited
notes String?
no setterinherited
plurals Plurals?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
no setterinherited
tags List<String>?
no setterinherited
text String
no setterinherited
variables List<Variable>?
no setterinherited
variants Map<String, Text>?
no setterinherited

Methods

applyVariables(Map<String, String>? toApply) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited